pub struct LuaChild { /* private fields */ }Expand description
A child entity implemented in Lua.
Can be used inside a LuaComponent to manage child entities.
Lua Table Format
Basic Child (no run capability)
{
id = "child-1",
status = "Idle", -- Optional, defaults to "Idle"
on_signal = function(sig)
return "Handled" | "Ignored" | "Abort"
end,
abort = function() -- Optional
end,
}Runnable Child (with run capability)
{
id = "worker-1",
run = function(input)
-- Perform work
return { success = true, data = { result = input.value * 2 } }
end,
on_signal = function(sig)
return "Handled"
end,
}Implementations
Sourceimpl LuaChild
impl LuaChild
Sourcepub fn from_table(
lua: Arc<Mutex<Lua>>,
table: Table,
sandbox: Arc<dyn SandboxPolicy>,
) -> Result<Self, LuaError>
pub fn from_table( lua: Arc<Mutex<Lua>>, table: Table, sandbox: Arc<dyn SandboxPolicy>, ) -> Result<Self, LuaError>
Sourcepub fn set_context(&mut self, context: Box<dyn ChildContext>)
pub fn set_context(&mut self, context: Box<dyn ChildContext>)
Sets the runtime context for this child.
The context enables spawning sub-children and emitting output. Call this before running the child.
Sourcepub fn has_context(&self) -> bool
pub fn has_context(&self) -> bool
Returns true if this child has a context set.
Sourcepub fn from_table_runnable(
lua: Arc<Mutex<Lua>>,
table: Table,
sandbox: Arc<dyn SandboxPolicy>,
) -> Result<Self, LuaError>
pub fn from_table_runnable( lua: Arc<Mutex<Lua>>, table: Table, sandbox: Arc<dyn SandboxPolicy>, ) -> Result<Self, LuaError>
Creates a LuaChild from a Lua table, requiring a run callback.
Use this when you need a RunnableChild that can execute work.
Arguments
lua- Shared Lua runtimetable- Lua table defining the child (must haverunfunction)sandbox- Sandbox policy for file operations and exec cwd
Errors
Returns error if table is missing required fields including run.
Sourcepub fn is_runnable(&self) -> bool
pub fn is_runnable(&self) -> bool
Returns true if this child has a run callback (is runnable).
Sourcepub fn simple(
lua: Arc<Mutex<Lua>>,
id: impl Into<String>,
sandbox: Arc<dyn SandboxPolicy>,
) -> Result<Self, LuaError>
pub fn simple( lua: Arc<Mutex<Lua>>, id: impl Into<String>, sandbox: Arc<dyn SandboxPolicy>, ) -> Result<Self, LuaError>
Creates a simple LuaChild with just an ID.
The on_signal callback will return Ignored for all signals.
Arguments
lua- Shared Lua runtimeid- Child identifiersandbox- Sandbox policy for file operations and exec cwd
Sourcepub fn from_script(
lua: Arc<Mutex<Lua>>,
script: &str,
sandbox: Arc<dyn SandboxPolicy>,
) -> Result<Self, LuaError>
pub fn from_script( lua: Arc<Mutex<Lua>>, script: &str, sandbox: Arc<dyn SandboxPolicy>, ) -> Result<Self, LuaError>
Creates a LuaChild from inline script content.
The script should return a Lua table with the child definition.
Arguments
lua- Shared Lua runtimescript- Inline Lua scriptsandbox- Sandbox policy for file operations and exec cwd
Errors
Returns error if script is invalid or missing required fields.